;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "nerd-icons-corfu" "20250729.1544"
  "Icons for Corfu via nerd-icons."
  '((emacs      "27.1")
    (nerd-icons "0.1.0"))
  :url "https://github.com/LuigiPiucco/nerd-icons-corfu"
  :commit "f821e953b1a3dc9b381bc53486aabf366bf11cb1"
  :revdesc "f821e953b1a3"
  :keywords '("convenience" "files" "icons")
  :authors '(("Luigi Sartor Piucco" . "luigipiucco@gmail.com"))
  :maintainers '(("Luigi Sartor Piucco" . "luigipiucco@gmail.com")))
